"""
This module will be available in templates as ``u``.

This module is also used to lookup custom template context providers, i.e. functions
following a special naming convention which are called to update the template context
before rendering resource's detail or index views.
"""



# coding: utf8
from __future__ import unicode_literals, print_function, division
import sys

from clldutils.path import Path
from clldutils.clilib import ArgumentParserWithLogging

from clldmpg import commands
assert commands


def main():  # pragma: no cover
    parser = ArgumentParserWithLogging('clldmpg')
    parser.add_argument("--project", help='clld app project dir', default=".", type=Path)
    parser.add_argument("--version", help='data version', default="1.0")
    sys.exit(parser.main())


if __name__ == '__main__':  # pragma: no cover
    main()



# coding: utf8
from __future__ import unicode_literals, print_function, division
import os
import re

from clldutils.clilib import command
from clldutils.path import Path, read_text
from clldutils.jsonlib import load, update


def app_name(project_dir):
    setup = read_text(project_dir / 'setup.py')
    match = re.search('main\s*=\s*(?P<name>[a-z0-9]+):main', setup)
    if match:
        return match.group('name')


@command()
def dl2cdstar(args):
    app = app_name(args.project)
    if not app:
        args.log.error('cannot parse package name')
        return

    try:
        from cdstarcat.catalog import Catalog
    except ImportError:
        args.log.error('pip install cdstarcat')
        return

    title_pattern = re.compile('%s (?P<version>[0-9.]+) - downloads' % re.escape(app))
    title = '{0} {1} - downloads'.format(app, args.version)
    pkg_dir = args.project.joinpath(app)
    with Catalog(
            Path(os.environ['CDSTAR_CATALOG']),
            cdstar_url=os.environ['CDSTAR_URL'],
            cdstar_user=os.environ['CDSTAR_USER'],
            cdstar_pwd=os.environ['CDSTAR_PWD']) as cat:
        obj = cat.api.get_object()
        obj.metadata = {"creator": "pycdstar", "title": title}
        if args.args:
            obj.metadata["description"] = args.args[0]
        for fname in pkg_dir.joinpath('static', 'download').iterdir():
            if fname.is_file() and not fname.name.startswith('.'):
                print(fname.name)
                obj.add_bitstream(
                    fname=fname.as_posix(), name=fname.name.replace('-', '_'))
        cat.add(obj)

    fname = pkg_dir.joinpath('static', 'downloads.json')
    with update(fname, default={}, indent=4) as downloads:
        for oid, spec in load(Path(os.environ['CDSTAR_CATALOG'])).items():
            if 'metadata' in spec and 'title' in spec['metadata']:
                match = title_pattern.match(spec['metadata']['title'])
                if match:
                    if match.group('version') not in downloads:
                        spec['oid'] = oid
                        downloads[match.group('version')] = spec
    args.log.info('{0} written'.format(fname))
    args.log.info('{0}'.format(os.environ['CDSTAR_CATALOG']))



import pytest


@pytest.mark.parametrize(
    "method,path",
    [
        ('get_html', '/'),
        ('get_html', '/legal'),
        ('get_html', '/download'),
    ])
def test_pages(app, method, path):
    getattr(app, method)(path)



from setuptools import setup, find_packages


setup(
    name='clldmpg',
    version='3.3.0',
    description=(
        'Python library supporting development of CLLD apps maintained by MPI SHH'),
    long_description='',
    classifiers=[
        "Intended Audience :: Developers",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: Implementation :: CPython",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: WSGI",
    ],
    keywords='web pyramid',
    author="Robert Forkel",
    author_email="forkel@shh.mpg.de",
    url="http://clld.org",
    license="Apache Software License",
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'clld>=4.2.1',
        'purl',
        'clldutils~=2.0',
    ],
    extras_require={
        'test': [
            'mock>=2.0',
            'pytest-clld',
            'pytest-mock',
            'coverage>=4.2',
            'pytest-cov',
        ],
        'dev': [
            'tox',
            'flake8',
            'wheel',
            'twine',
        ],
    },
    message_extractors={'src/clldmpg': [
        ('**.py', 'python', None),
        ('**.mako', 'mako', None),
        ('static/**', 'ignore', None)]},
    entry_points={
        'pyramid.scaffold': ['clldmpg_app=clldmpg.scaffolds:ClldAppTemplate'],
        'console_scripts': ['clldmpg=clldmpg.__main__:main'],
    },
)



from pyramid.response import Response

from clld.interfaces import IOlacConfig
from clld.web.views.olac import OlacConfig, Participant, Institution


class MpgOlacConfig(OlacConfig):
    def admin(self, req):
        return Participant("Admin", 'Robert Forkel', 'forkel@shh.mpg.de')

    def description(self, req):
        res = OlacConfig.description(self, req)
        res['institution'] = Institution(
            'Max Planck Institute for the Science of Human History',
            'http://shh.mpg.de',
            'Jena, Germany')
        return res


def includeme(config):
    config.include('clld.web.app')
    config.registry.registerUtility(MpgOlacConfig(), IOlacConfig)
    config.add_static_view('clldmpg-static', 'clldmpg:static')
    config.add_settings({'clld.publisher_logo': 'clldmpg:static/minerva.png'})
    config.add_settings(
        {'clld.privacy_policy_url': 'https://www.shh.mpg.de/138116/privacy-policy'})
    config.add_route('google-site-verification', 'googlebbc8f4da1abdc58b.html')
    config.add_view(
        lambda r: Response('google-site-verification: googlebbc8f4da1abdc58b.html'),
        route_name='google-site-verification')
